﻿using System;
using System.Collections.ObjectModel;
using System.Windows.Media;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.GanttView;
using Telerik.Windows.Controls.Scheduling;

namespace ShowIterationSeparator
{
    public class ViewModel : ViewModelBase
    {
        private static readonly Brush redBrush = new SolidColorBrush(Colors.Red);
        private static readonly Brush greenBrush = new SolidColorBrush(Colors.Green);

        private IDateRange visibleRange;
        public IDateRange VisibleRange
        {
            get { return this.visibleRange; }
            set
            {
                if (this.visibleRange != value)
                {
                    this.visibleRange = value;
                    this.OnPropertyChanged(() => this.VisibleRange);
                }
            }
        }

        private ObservableCollection<IGanttTask> tasks;
        public ObservableCollection<IGanttTask> Tasks
        {
            get { return this.tasks; }
            set
            {
                if (this.tasks != value)
                {
                    this.tasks = value;
                    this.OnPropertyChanged(() => this.Tasks);
                }
            }
        }

        private CustomTimelineBehavior timeLineBaselineBehavior;
        public CustomTimelineBehavior TimeLineBaselineBehavior
        {
            get
            {
                return timeLineBaselineBehavior;
            }

            set
            {
                timeLineBaselineBehavior = value;
                OnPropertyChanged(() => this.TimeLineBaselineBehavior);
            }
        }

        public ViewModel()
        {
            var start = DateTime.Today;

            this.VisibleRange = new DateRange(start, start.AddDays(7));

            this.TimeLineBaselineBehavior = new CustomTimelineBehavior();
            this.TimeLineBaselineBehavior.VisibleRange = this.VisibleRange;

            var childTask1 = new ColoredTask { Title = "Red Task", Start = start, End = start.AddDays(1), Background = redBrush };
            var childTask2 = new ColoredTask { Title = "Green Task", Start = start.AddDays(2), End = start.AddDays(3), Background = greenBrush, ShowIterationSeparator = true };

            var iterationTask1 = new GanttTask(start, start.AddDays(3), "Iteration Task") { Children = { childTask1, childTask2 } };

            var childTask21 = new ColoredTask { Title = "Green Task", Start = start, End = start.AddDays(1), Background = greenBrush };
            var childTask22 = new ColoredTask { Title = "Red Task", Start = start.AddDays(2), End = start.AddDays(3), Background = redBrush, ShowIterationSeparator = true };

            var iterationTask2 = new GanttTask(start, start.AddDays(3), "Iteration Task") { Children = { childTask21, childTask22 } };

            this.Tasks = new ObservableCollection<IGanttTask>();
            this.Tasks.Add(iterationTask1);
            this.Tasks.Add(iterationTask2);
        }
    }
}
